@@ -13,6 +13,7 @@
 #define USB_DEVICE_ID_RAZER_ANANSI 0x010F
 #define USB_DEVICE_ID_RAZER_NOSTROMO 0x0111
 #define USB_DEVICE_ID_RAZER_ORBWEAVER 0x0113
+#define USB_DEVICE_ID_RAZER_DEATHSTALKER_ESSENTIAL 0x0118
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_ULTIMATE_2013 0x011A
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_STEALTH 0x011B
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_TE_2014 0x011C
@@ -60,6 +61,7 @@
 #define USB_DEVICE_ID_RAZER_BLADE_MID_2019_MERCURY 0x0245
 #define USB_DEVICE_ID_RAZER_BLADE_2019_BASE 0x0246
 #define USB_DEVICE_ID_RAZER_BLADE_STEALTH_LATE_2019 0x024A
+#define USB_DEVICE_ID_RAZER_BLADE_ADV_LATE_2019 0x024B
 #define USB_DEVICE_ID_RAZER_BLADE_PRO_LATE_2019 0x024C
 #define USB_DEVICE_ID_RAZER_BLADE_STUDIO_EDITION_2019 0x024D
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3 0x024E
@@ -85,10 +87,24 @@
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_MINI_WIRELESS 0x0271
 #define USB_DEVICE_ID_RAZER_BLADE_15_ADV_MID_2021 0x0276
 #define USB_DEVICE_ID_RAZER_BLADE_17_PRO_MID_2021 0x0279
+#define USB_DEVICE_ID_RAZER_BLADE_15_BASE_2022 0x027A
 #define USB_DEVICE_ID_RAZER_HUNTSMAN_MINI_ANALOG 0x0282
+#define USB_DEVICE_ID_RAZER_BLACKWIDOW_V4 0x0287
 #define USB_DEVICE_ID_RAZER_BLADE_15_ADV_EARLY_2022 0x028A
 #define USB_DEVICE_ID_RAZER_BLADE_17_2022 0x028B
+#define USB_DEVICE_ID_RAZER_BLADE_14_2022 0x028C
+#define USB_DEVICE_ID_RAZER_BLACKWIDOW_V4_PRO 0x028D
+#define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_WIRELESS 0x0290
+#define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_WIRED 0x0292
+#define USB_DEVICE_ID_RAZER_ORNATA_V3_X 0x0294
 #define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2 0x0295
+#define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_TKL_WIRELESS 0x0296
+#define USB_DEVICE_ID_RAZER_DEATHSTALKER_V2_PRO_TKL_WIRED 0x0298
+#define USB_DEVICE_ID_RAZER_BLADE_15_2023 0x029E
+#define USB_DEVICE_ID_RAZER_BLADE_16_2023 0x029F
+#define USB_DEVICE_ID_RAZER_BLADE_18_2023 0x02A0
+#define USB_DEVICE_ID_RAZER_ORNATA_V3 0x02A1
+#define USB_DEVICE_ID_RAZER_ORNATA_V3_X_ALT 0x02A2
 #define USB_DEVICE_ID_RAZER_BLACKWIDOW_V3_TK 0x0A24
 
 /* Each keyboard report has 90 bytes*/
@@ -110,7 +126,6 @@
 
 #define RAZER_BLACKWIDOW_ULTIMATE_2016_EFFECT_STARLIGHT 0x19
 
-
 #define RAZER_BLACKWIDOW_CHROMA_EFFECT_SET_KEYS 9 //update profile needs to be called after setting keys to reflect changes
 #define RAZER_BLACKWIDOW_CHROMA_EFFECT_RESET 10
 #define RAZER_BLACKWIDOW_CHROMA_EFFECT_UNKNOWN 11
@@ -118,16 +133,12 @@
 #define RAZER_BLACKWIDOW_CHROMA_EFFECT_UNKNOWN3 13
 #define RAZER_BLACKWIDOW_CHROMA_EFFECT_UNKNOWN4 14
 
-
 #define RAZER_BLACKWIDOW_CHROMA_ROW_LEN 0x16
 #define RAZER_BLACKWIDOW_CHROMA_ROWS_NUM 6
 
-
 #define RAZER_STEALTH_ROW_LEN 0x10
 #define RAZER_STEALTH_ROWS_NUM 6
 
-
-
 #define RAZER_BLACKWIDOW_CHROMA_WAIT_MS 1
 #define RAZER_BLACKWIDOW_CHROMA_WAIT_MIN_US 600
 #define RAZER_BLACKWIDOW_CHROMA_WAIT_MAX_US 800
@@ -135,11 +146,19 @@
 #define RAZER_BLACKWIDOW_V3_WIRELESS_WAIT_MIN_US 4900
 #define RAZER_BLACKWIDOW_V3_WIRELESS_WAIT_MAX_US 5000
 
+#define RAZER_DEATHSTALKER_V2_WIRELESS_WAIT_MIN_US 4900
+#define RAZER_DEATHSTALKER_V2_WIRELESS_WAIT_MAX_US 5000
+
 #define RAZER_FIREFLY_WAIT_MIN_US 900
 #define RAZER_FIREFLY_WAIT_MAX_US 1000
 
-
 struct razer_kbd_device {
+    struct usb_device *usb_dev;
+    struct mutex lock;
+    unsigned char usb_interface_protocol;
+    unsigned short usb_vid;
+    unsigned short usb_pid;
+
     unsigned int fn_on;
     DECLARE_BITMAP(pressed_fn, KEY_CNT);
 
@@ -147,6 +166,4 @@ struct razer_kbd_device {
     unsigned char left_alt_on;
 };
 
-
-
 #endif
