@@ -82,17 +82,20 @@
 #define USB_DEVICE_ID_RAZER_VIPER_MINI_SE_WIRED 0x009E
 #define USB_DEVICE_ID_RAZER_VIPER_MINI_SE_WIRELESS 0x009F
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V2_LITE 0x00A1
+#define USB_DEVICE_ID_RAZER_COBRA 0x00A3
 #define USB_DEVICE_ID_RAZER_VIPER_V2_PRO_WIRED 0x00A5
 #define USB_DEVICE_ID_RAZER_VIPER_V2_PRO_WIRELESS 0x00A6
 #define USB_DEVICE_ID_RAZER_BASILISK_V3_PRO_WIRED 0x00AA
 #define USB_DEVICE_ID_RAZER_BASILISK_V3_PRO_WIRELESS 0x00AB
-#define USB_DEVICE_ID_RAZER_COBRA_PRO 0x00B0
+#define USB_DEVICE_ID_RAZER_COBRA_PRO_WIRED 0x00AF
+#define USB_DEVICE_ID_RAZER_COBRA_PRO_WIRELESS 0x00B0
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V3 0x00B2
 #define USB_DEVICE_ID_RAZER_HYPERPOLLING_WIRELESS_DONGLE 0x00B3
 #define USB_DEVICE_ID_RAZER_NAGA_V2_HYPERSPEED_RECEIVER 0x00B4
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V3_PRO_WIRED 0x00B6
 #define USB_DEVICE_ID_RAZER_DEATHADDER_V3_PRO_WIRELESS 0x00B7
 #define USB_DEVICE_ID_RAZER_VIPER_V3_HYPERSPEED 0x00B8
+#define USB_DEVICE_ID_RAZER_BASILISK_V3_X_HYPERSPEED 0x00B9
 
 /* Each keyboard report has 90 bytes*/
 #define RAZER_REPORT_LEN 0x5A
